Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Scope.LoggingSourcelogging.ml - Custom logging and error messages
Represents the severity of a log statement
For exits, their appropriate return code and the message type
ANSI encoding for bold text
ANSI encoding for red text
ANSI encoding for orange text
ANSI encoding for yellow text
ANSI encoding for plain text
ANSI encoding for bold red text
ANSI encoding for bold orange text
ANSI encoding for bold yellow text
A fatal log statement that immediately exits the program
Prints log statements to stdout/stderr